@@ -1,32 +1,24 @@
-#![feature(test)]
-
-extern crate test;
-
 use pretty_assertions::assert_eq;
 use serde::Deserialize;
 use serde_json::Value;
 use std::{
     cmp::Ordering,
-    collections::HashMap,
     env,
     fs::File,
     io,
     io::Read,
     path::{Path, PathBuf},
 };
-use swc_common::{comments::SingleThreadedComments, input::StringInput, FromVariant, Mark};
+use swc_common::{
+    collections::AHashMap, comments::SingleThreadedComments, input::StringInput, FromVariant, Mark,
+};
 use swc_ecma_ast::*;
 use swc_ecma_codegen::Emitter;
 use swc_ecma_parser::{EsConfig, Parser, Syntax};
 use swc_ecma_preset_env::{preset_env, Config, FeatureOrModule, Mode, Targets, Version};
 use swc_ecma_utils::drop_span;
-use swc_ecma_visit::as_folder;
-use swc_ecma_visit::FoldWith;
-use swc_ecma_visit::VisitMut;
-use test::{test_main, ShouldPanic, TestDesc, TestDescAndFn, TestFn, TestName, TestType};
-use testing::NormalizedOutput;
-use testing::Tester;
-use walkdir::WalkDir;
+use swc_ecma_visit::{as_folder, FoldWith, VisitMut};
+use testing::{NormalizedOutput, Tester};
 
 /// options.json file
 #[derive(Debug, Deserialize)]
@@ -73,7 +65,7 @@ struct PresetConfig {
 #[serde(untagged)]
 pub enum CoreJs {
     Ver(Version),
-    Val(HashMap<String, Value>),
+    Val(AHashMap<String, Value>),
 }
 
 impl Default for CoreJs {
@@ -120,57 +112,6 @@ enum Error {
     Msg(String),
 }
 
-fn load() -> Result<Vec<TestDescAndFn>, Error> {
-    let mut tests = vec![];
-    let mut dir = PathBuf::from(env::var("CARGO_MANIFEST_DIR")?);
-    dir.push("tests");
-    dir.push("fixtures");
-
-    for entry in WalkDir::new(&dir) {
-        let e = entry?;
-        println!("File: {}", e.path().display());
-
-        if e.metadata()?.is_file() {
-            continue;
-        }
-
-        match e.path().join("input.mjs").metadata() {
-            Ok(e) if e.is_file() => {}
-            _ => continue,
-        }
-
-        let cfg: BabelOptions = serde_json::from_reader(File::open(e.path().join("options.json"))?)
-            .map_err(|err| Error::Msg(format!("failed to parse options.json: {}", err)))?;
-        assert_eq!(cfg.presets.len(), 1);
-        let cfg = cfg.presets.into_iter().map(|v| v.1).next().unwrap();
-
-        let name = e
-            .path()
-            .strip_prefix(&dir)
-            .expect("failed to strip prefix")
-            .display()
-            .to_string();
-        tests.push(TestDescAndFn {
-            desc: TestDesc {
-                test_type: TestType::IntegrationTest,
-                ignore: e.path().to_string_lossy().contains(".")
-                    || env::var("TEST")
-                        .map(|s| !name.contains(&s))
-                        .unwrap_or(false),
-                name: TestName::DynTestName(name),
-                allow_fail: false,
-                should_panic: ShouldPanic::No,
-            },
-            testfn: TestFn::DynTestFn(Box::new(move || {
-                //
-                exec(cfg, e.path().to_path_buf()).expect("failed to run test")
-            })),
-        });
-    }
-
-    Ok(tests)
-}
-
 fn exec(c: PresetConfig, dir: PathBuf) -> Result<(), Error> {
     println!("Config: {:?}", c);
 
@@ -345,12 +286,19 @@ fn read(p: &Path) -> String {
     buf
 }
 
-#[test]
-fn fixtures() {
-    let tests = load().expect("failed to load fixtures");
+#[testing::fixture("tests/fixtures/**/input.mjs")]
+fn fixture(input: PathBuf) {
+    let entry_dir = input.parent().unwrap().to_path_buf();
+    println!("File: {}", entry_dir.display());
 
-    let args: Vec<_> = env::args().collect();
-    test_main(&args, tests, Some(test::Options::new()));
+    let cfg: BabelOptions =
+        serde_json::from_reader(File::open(entry_dir.join("options.json")).unwrap())
+            .map_err(|err| Error::Msg(format!("failed to parse options.json: {}", err)))
+            .unwrap();
+    assert_eq!(cfg.presets.len(), 1);
+    let cfg = cfg.presets.into_iter().map(|v| v.1).next().unwrap();
+
+    exec(cfg, entry_dir).expect("failed to run test")
 }
 
 struct Normalizer;
